@@ -30,7 +30,7 @@ if TYPE_CHECKING:
 else:
     try:
         from yaml import CSafeLoader as SafeLoader
-    except ImportError:
+    except ImportError:  # pragma: no cover
         from yaml import SafeLoader
 
     try:
@@ -194,8 +194,13 @@ def generate(
     enum_field_as_literal: Optional[LiteralType] = None,
     set_default_enum_member: bool = False,
     strict_nullable: bool = False,
+    use_generic_container_types: bool = False,
+    enable_faux_immutability: bool = False,
 ) -> None:
     input_text: Optional[str] = None
+    if isinstance(input_, Path) and not input_.is_absolute():
+        input_ = input_.expanduser().resolve()
+
     if input_file_type == InputFileType.Auto:
         try:
             input_text_ = (
@@ -285,6 +290,8 @@ def generate(
         enum_field_as_literal=enum_field_as_literal,
         set_default_enum_member=set_default_enum_member,
         strict_nullable=strict_nullable,
+        use_generic_container_types=use_generic_container_types,
+        enable_faux_immutability=enable_faux_immutability,
     )
 
     with chdir(output):
