@@ -61,6 +61,10 @@ IMPORT_LIST = Import.from_full_path('typing.List')
 IMPORT_UNION = Import.from_full_path('typing.Union')
 IMPORT_OPTIONAL = Import.from_full_path('typing.Optional')
 IMPORT_LITERAL = Import.from_full_path('typing.Literal')
+IMPORT_SEQUENCE = Import.from_full_path('typing.Sequence')
+IMPORT_MAPPING = Import.from_full_path('typing.Mapping')
+IMPORT_ABC_SEQUENCE = Import.from_full_path('collections.abc.Sequence')
+IMPORT_ABC_MAPPING = Import.from_full_path('collections.abc.Mapping')
 IMPORT_ENUM = Import.from_full_path('enum.Enum')
 IMPORT_ANNOTATIONS = Import.from_full_path('__future__.annotations')
 IMPORT_DICT = Import.from_full_path('typing.Dict')
