@@ -3,12 +3,16 @@ from typing import Any, Dict, Set
 
 from datamodel_code_generator.format import PythonVersion
 from datamodel_code_generator.imports import (
+    IMPORT_ABC_MAPPING,
+    IMPORT_ABC_SEQUENCE,
     IMPORT_ANY,
     IMPORT_DATE,
     IMPORT_DATETIME,
     IMPORT_DECIMAL,
     IMPORT_DICT,
     IMPORT_LIST,
+    IMPORT_MAPPING,
+    IMPORT_SEQUENCE,
     IMPORT_UUID,
 )
 from datamodel_code_generator.model.pydantic.imports import (
@@ -64,7 +68,7 @@ type_map: Dict[Types, DataType] = {
         is_func=True,
         # https://github.com/horejsek/python-fastjsonschema/blob/61c6997a8348b8df9b22e029ca2ba35ef441fbb8/fastjsonschema/draft04.py#L31
         kwargs={
-            'regex': "'^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]{0,61}[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]{0,61}[A-Za-z0-9])\Z'"
+            'regex': r"r'^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]{0,61}[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]{0,61}[A-Za-z0-9])\Z'"
         },
     ),
     Types.ipv4: DataType(type='IPv4Address', imports_=[IMPORT_IPV4ADDRESS]),
@@ -81,6 +85,25 @@ standard_collections_type_map = {
     Types.object: DataType(type='dict[str, Any]', imports_=[IMPORT_ANY,],),
     Types.array: DataType(type='list[Any]', imports_=[IMPORT_ANY]),
 }
+
+generic_container_type_map = {
+    **type_map,
+    Types.object: DataType(
+        type='Mapping[str, Any]', imports_=[IMPORT_MAPPING, IMPORT_ANY],
+    ),
+    Types.array: DataType(type='Sequence[Any]', imports_=[IMPORT_SEQUENCE, IMPORT_ANY]),
+}
+
+generic_container_standard_collections_type_map = {
+    **type_map,
+    Types.object: DataType(
+        type='Mapping[str, Any]', imports_=[IMPORT_ABC_MAPPING, IMPORT_ANY],
+    ),
+    Types.array: DataType(
+        type='Sequence[Any]', imports_=[IMPORT_ABC_SEQUENCE, IMPORT_ANY]
+    ),
+}
+
 kwargs_schema_to_model = {
     'exclusiveMinimum': 'gt',
     'minimum': 'ge',
@@ -118,11 +141,23 @@ class DataTypeManager(_DataTypeManager):
         self,
         python_version: PythonVersion = PythonVersion.PY_37,
         use_standard_collections: bool = False,
+        use_generic_container_types: bool = False,
     ):
-        super().__init__(python_version, use_standard_collections)
-        self.type_map: Dict[
-            Types, DataType
-        ] = standard_collections_type_map if use_standard_collections else type_map
+        super().__init__(
+            python_version, use_standard_collections, use_generic_container_types
+        )
+
+        self.type_map: Dict[Types, DataType]
+        if use_standard_collections:
+            if use_generic_container_types:
+                self.type_map = generic_container_standard_collections_type_map
+            else:
+                self.type_map = standard_collections_type_map
+        else:
+            if use_generic_container_types:
+                self.type_map = generic_container_type_map
+            else:
+                self.type_map = type_map
 
     def get_data_int_type(self, types: Types, **kwargs: Any) -> DataType:
         data_type_kwargs = transform_kwargs(kwargs, number_kwargs)
@@ -177,7 +212,7 @@ class DataTypeManager(_DataTypeManager):
         data_type_kwargs = transform_kwargs(kwargs, string_kwargs)
         if data_type_kwargs:
             if 'regex' in data_type_kwargs:
-                data_type_kwargs['regex'] = f'\'{data_type_kwargs["regex"]}\''
+                data_type_kwargs['regex'] = f'r\'{data_type_kwargs["regex"]}\''
             return self.data_type(
                 type='constr',
                 is_func=True,
