@@ -239,9 +239,11 @@ class Parser(ABC):
         enum_field_as_literal: Optional[LiteralType] = None,
         set_default_enum_member: bool = False,
         strict_nullable: bool = False,
+        use_generic_container_types: bool = False,
+        enable_faux_immutability: bool = False,
     ):
         self.data_type_manager: DataTypeManager = data_type_manager_type(
-            target_python_version, use_standard_collections
+            target_python_version, use_standard_collections, use_generic_container_types
         )
         self.data_model_type: Type[DataModel] = data_model_type
         self.data_model_root_type: Type[DataModel] = data_model_root_type
@@ -265,6 +267,8 @@ class Parser(ABC):
         self.enum_field_as_literal: Optional[LiteralType] = enum_field_as_literal
         self.set_default_enum_member: bool = set_default_enum_member
         self.strict_nullable: bool = strict_nullable
+        self.use_generic_container_types: bool = use_generic_container_types
+        self.enable_faux_immutability: bool = enable_faux_immutability
 
         self.current_source_path: Optional[Path] = None
 
@@ -286,6 +290,9 @@ class Parser(ABC):
         if allow_population_by_field_name:
             self.extra_template_data[ALL_MODEL]['allow_population_by_field_name'] = True
 
+        if enable_faux_immutability:
+            self.extra_template_data[ALL_MODEL]['allow_mutation'] = False
+
         self.model_resolver = ModelResolver(aliases=aliases)
         self.field_preprocessors: List[
             Callable[[DataModelFieldBase, DataModel], None]
@@ -409,7 +416,7 @@ class Parser(ABC):
 
                     if data_type.reference.source in models:
                         # Referenced model is in the same file. we don't need to import the model
-                        data_type.type = data_type.name
+                        data_type.alias = data_type.name
                         continue
                     elif (
                         isinstance(self.source, Path)
@@ -437,7 +444,7 @@ class Parser(ABC):
                     if name in model.reference_classes:
                         model.reference_classes.remove(name)
                         model.reference_classes.add(new_name)
-                    data_type.type = new_name
+                    data_type.alias = new_name
 
                     if (
                         full_name
@@ -497,7 +504,7 @@ class Parser(ABC):
                         if data_type.type:
                             duplicated_model = duplicated_models.get(data_type.type)
                             if duplicated_model:
-                                data_type.type = duplicated_model.name
+                                data_type.alias = duplicated_model.name
                                 data_type.reference = duplicated_model.reference
             if self.set_default_enum_member:
                 for model in models:  # pragma: no cover
