@@ -180,6 +180,7 @@ class JsonSchemaObject(BaseModel):
             and not self.allOf
             and not self.oneOf
             and not self.anyOf
+            and not self.ref
         )
 
     @cached_property
@@ -249,6 +250,8 @@ class JsonSchemaParser(Parser):
         enum_field_as_literal: Optional[LiteralType] = None,
         set_default_enum_member: bool = False,
         strict_nullable: bool = False,
+        use_generic_container_types: bool = False,
+        enable_faux_immutability: bool = False,
     ):
         super().__init__(
             source=source,
@@ -278,6 +281,8 @@ class JsonSchemaParser(Parser):
             enum_field_as_literal=enum_field_as_literal,
             set_default_enum_member=set_default_enum_member,
             strict_nullable=strict_nullable,
+            use_generic_container_types=use_generic_container_types,
+            enable_faux_immutability=enable_faux_immutability,
         )
 
         self.remote_object_cache: Dict[str, Dict[str, Any]] = {}
@@ -393,7 +398,11 @@ class JsonSchemaParser(Parser):
         return self.parse_list_item(name, obj.oneOf, path)
 
     def parse_all_of(
-        self, name: str, obj: JsonSchemaObject, path: List[str]
+        self,
+        name: str,
+        obj: JsonSchemaObject,
+        path: List[str],
+        ignore_duplicate_model: bool = False,
     ) -> DataType:
         fields: List[DataModelFieldBase] = []
         base_classes: List[DataType] = []
@@ -409,6 +418,9 @@ class JsonSchemaParser(Parser):
                 base_classes.append(self.get_ref_data_type(all_of_item.ref))
             else:
                 fields.extend(self.parse_object_fields(all_of_item, path))
+        # ignore an undetected object
+        if ignore_duplicate_model and not fields and len(base_classes) == 1:
+            return base_classes[0]
         reference = self.model_resolver.add(
             path, name, class_name=True, unique=True, loaded=True
         )
@@ -460,7 +472,9 @@ class JsonSchemaParser(Parser):
             elif field.oneOf:
                 field_type = self.parse_one_of(field_name, field, [*path, field_name])
             elif field.allOf:
-                field_type = self.parse_all_of(field_name, field, [*path, field_name])
+                field_type = self.parse_all_of(
+                    field_name, field, [*path, field_name], ignore_duplicate_model=True
+                )
             elif field.is_object:
                 if field.properties:
                     field_type = self.parse_object(
@@ -510,7 +524,25 @@ class JsonSchemaParser(Parser):
                                 field.additionalProperties,
                                 [*path, field_name],
                             )
-
+                    elif field.additionalProperties.anyOf:
+                        additional_properties_type = self.parse_any_of(
+                            field_class_name,
+                            field.additionalProperties,
+                            [*path, field_name],
+                        )
+                    elif field.additionalProperties.oneOf:
+                        additional_properties_type = self.parse_one_of(
+                            field_class_name,
+                            field.additionalProperties,
+                            [*path, field_name],
+                        )
+                    elif field.additionalProperties.allOf:
+                        additional_properties_type = self.parse_all_of(
+                            field_class_name,
+                            field.additionalProperties,
+                            [*path, field_name],
+                            ignore_duplicate_model=True,
+                        )
                     else:
                         additional_properties_type = self.parse_root_type(
                             field_class_name,
@@ -557,7 +589,9 @@ class JsonSchemaParser(Parser):
                     required=required,
                     alias=alias,
                     constraints=constraints,
-                    nullable=field.nullable if self.strict_nullable else None,
+                    nullable=field.nullable
+                    if self.strict_nullable and (field.has_default or required)
+                    else None,
                 )
             )
         return fields
@@ -611,7 +645,7 @@ class JsonSchemaParser(Parser):
         item_obj_data_types: List[DataType] = []
         for index, item in enumerate(items):
             field_path = [*path, str(index)]
-            if item.has_constraint:
+            if item.has_constraint and (obj.has_constraint or self.field_constraints):
                 item_obj_data_types.append(
                     self.parse_root_type(
                         self.model_resolver.add(
@@ -633,6 +667,8 @@ class JsonSchemaParser(Parser):
                 )
             elif item.anyOf:
                 item_obj_data_types.append(self.parse_any_of(name, item, field_path))
+            elif item.oneOf:
+                item_obj_data_types.append(self.parse_one_of(name, item, field_path))
             elif item.allOf:
                 item_obj_data_types.append(
                     self.parse_all_of(
@@ -641,6 +677,7 @@ class JsonSchemaParser(Parser):
                         ).name,
                         item,
                         field_path,
+                        ignore_duplicate_model=True,
                     )
                 )
             elif item.enum:
@@ -664,15 +701,16 @@ class JsonSchemaParser(Parser):
                 item_obj_data_types.append(self.get_data_type(item))
         if self.force_optional_for_required_fields:
             required: bool = False
+            nullable: Optional[bool] = None
         else:
+            required = not (
+                obj.has_default and self.apply_default_values_for_required_fields
+            )
             if self.strict_nullable:
-                required = not (
-                    obj.has_default and self.apply_default_values_for_required_fields
-                )
+                nullable = obj.nullable if obj.has_default or required else True
             else:
-                required = not obj.nullable and not (
-                    obj.has_default and self.apply_default_values_for_required_fields
-                )
+                required = not obj.nullable and required
+                nullable = None
         return self.data_model_field_type(
             data_type=self.data_type(data_types=item_obj_data_types, is_list=True,),
             example=obj.example,
@@ -682,7 +720,7 @@ class JsonSchemaParser(Parser):
             title=obj.title,
             required=required,
             constraints=obj.dict(),
-            nullable=obj.nullable if self.strict_nullable else None,
+            nullable=nullable,
         )
 
     def parse_array(
@@ -710,25 +748,22 @@ class JsonSchemaParser(Parser):
         path: List[str],
         additional_properties: Optional[JsonSchemaObject] = None,
     ) -> DataType:
-        if obj.type:
-            data_type: DataType = self.get_data_type(obj)
+        if obj.ref:
+            data_type: DataType = self.get_ref_data_type(obj.ref)
+        elif obj.type:
+            data_type = self.get_data_type(obj)
         elif obj.anyOf:
             data_type = self.parse_any_of(name, obj, [*path, name])
-        elif obj.ref:
-            data_type = self.get_ref_data_type(obj.ref)
+        elif obj.oneOf:
+            data_type = self.parse_one_of(name, obj, [*path, name])
         else:
             data_type = self.data_type_manager.get_data_type(Types.any)
         if self.force_optional_for_required_fields:
             required: bool = False
         else:
-            if self.strict_nullable:
-                required = not (
-                    obj.has_default and self.apply_default_values_for_required_fields
-                )
-            else:
-                required = not obj.nullable and not (
-                    obj.has_default and self.apply_default_values_for_required_fields
-                )
+            required = not obj.nullable and not (
+                obj.has_default and self.apply_default_values_for_required_fields
+            )
         reference = self.model_resolver.add(path, name, loaded=True)
         self.set_title(name, obj)
         self.set_additional_properties(name, additional_properties or obj)
@@ -771,7 +806,15 @@ class JsonSchemaParser(Parser):
             )
         enum_fields: List[DataModelFieldBase] = []
 
-        for i, enum_part in enumerate(obj.enum):
+        if None in obj.enum and obj.type == 'string':
+            # Nullable is valid in only OpenAPI
+            nullable: bool = True
+            enum_times = [e for e in obj.enum if e]
+        else:
+            enum_times = obj.enum
+            nullable = False
+
+        for i, enum_part in enumerate(enum_times):
             if obj.type == 'string' or isinstance(enum_part, str):
                 default = f"'{enum_part}'"
                 field_name = enum_part
@@ -794,7 +837,28 @@ class JsonSchemaParser(Parser):
                     required=True,
                 )
             )
-        reference = self.model_resolver.add(
+
+        if not nullable:
+            reference = self.model_resolver.add(
+                path,
+                name,
+                class_name=True,
+                singular_name=singular_name,
+                singular_name_suffix='Enum',
+                unique=True,
+                loaded=True,
+            )
+            enum = Enum(
+                reference.name,
+                fields=enum_fields,
+                path=self.current_source_path,
+                description=obj.description if self.use_schema_description else None,
+                reference=reference,
+            )
+            self.append_result(enum)
+            return self.data_type.from_reference(reference)
+
+        root_reference = self.model_resolver.add(
             path,
             name,
             class_name=True,
@@ -803,15 +867,44 @@ class JsonSchemaParser(Parser):
             unique=True,
             loaded=True,
         )
+        enum_reference = self.model_resolver.add(
+            [*path, 'Enum'],
+            f'{root_reference.name}Enum',
+            class_name=True,
+            singular_name=singular_name,
+            singular_name_suffix='Enum',
+            unique=True,
+            loaded=True,
+        )
         enum = Enum(
-            reference.name,
+            enum_reference.name,
             fields=enum_fields,
             path=self.current_source_path,
             description=obj.description if self.use_schema_description else None,
-            reference=reference,
+            reference=enum_reference,
         )
         self.append_result(enum)
-        return self.data_type.from_reference(reference)
+        data_model_root_type = self.data_model_root_type(
+            name,
+            [
+                self.data_model_field_type(
+                    data_type=self.data_type.from_reference(enum_reference),
+                    description=obj.description,
+                    example=obj.example,
+                    examples=obj.examples,
+                    default=obj.default,
+                    required=False,
+                    nullable=True,
+                )
+            ],
+            custom_base_class=self.base_class,
+            custom_template_dir=self.custom_template_dir,
+            extra_template_data=self.extra_template_data,
+            path=self.current_source_path,
+            reference=root_reference,
+        )
+        self.append_result(data_model_root_type)
+        return self.data_type.from_reference(root_reference)
 
     def _get_ref_body(self, ref: str) -> Dict[Any, Any]:
         if is_url(ref):
@@ -995,7 +1088,10 @@ class JsonSchemaParser(Parser):
                         raise InvalidClassNameError(obj_name)
                 self._parse_file(self.raw_obj, obj_name, path_parts)
 
-        # resolve unparsed json pointer
+        self._resolve_unparsed_json_pointer()
+
+    def _resolve_unparsed_json_pointer(self) -> None:
+        model_count: int = len(self.results)
         for source in self.iter_source:
             path_parts = list(source.path.parts)
             reserved_refs = self.reserved_refs.get(tuple(path_parts))  # type: ignore
@@ -1019,6 +1115,10 @@ class JsonSchemaParser(Parser):
                     self.raw_obj = load_yaml(source.text)
                     self.parse_json_pointer(self.raw_obj, reserved_ref, path_parts)
 
+        if model_count != len(self.results):
+            # New model have been generated. It try to resolve json pointer again.
+            self._resolve_unparsed_json_pointer()
+
     def parse_json_pointer(
         self, raw: Dict[str, Any], ref: str, path_parts: List[str]
     ) -> None:
