@@ -6,10 +6,14 @@ from pydantic import BaseModel
 
 from datamodel_code_generator.format import PythonVersion
 from datamodel_code_generator.imports import (
+    IMPORT_ABC_MAPPING,
+    IMPORT_ABC_SEQUENCE,
     IMPORT_DICT,
     IMPORT_LIST,
     IMPORT_LITERAL,
+    IMPORT_MAPPING,
     IMPORT_OPTIONAL,
+    IMPORT_SEQUENCE,
     IMPORT_UNION,
     Import,
 )
@@ -31,6 +35,8 @@ class DataType(BaseModel):
     is_list: bool = False
     literals: List[str] = []
     use_standard_collections: bool = False
+    use_generic_container: bool = False
+    alias: Optional[str] = None
 
     @classmethod
     def from_reference(cls, reference: Reference, is_list: bool = False) -> 'DataType':
@@ -69,7 +75,9 @@ class DataType(BaseModel):
             self.unresolved_types.add(self.type)
         for type_ in self.data_types:
             if type_.type == 'Any' and type_.is_optional:
-                if any(t for t in self.data_types if t.type != 'Any'):
+                if any(
+                    t for t in self.data_types if t.type != 'Any'
+                ):  # pragma: no cover
                     self.is_optional = True
                     self.data_types = [
                         t
@@ -83,7 +91,20 @@ class DataType(BaseModel):
             (len(self.data_types) > 1, IMPORT_UNION),
             (any(self.literals), IMPORT_LITERAL),
         )
-        if not self.use_standard_collections:
+        if self.use_generic_container:
+            if self.use_standard_collections:
+                imports = (
+                    *imports,
+                    (self.is_list, IMPORT_ABC_SEQUENCE),
+                    (self.is_dict, IMPORT_ABC_MAPPING),
+                )
+            else:
+                imports = (
+                    *imports,
+                    (self.is_list, IMPORT_SEQUENCE),
+                    (self.is_dict, IMPORT_MAPPING),
+                )
+        elif not self.use_standard_collections:
             imports = (
                 *imports,
                 (self.is_list, IMPORT_LIST),
@@ -98,13 +119,12 @@ class DataType(BaseModel):
 
     @property
     def type_hint(self) -> str:
-        if self.type:
+        type_: Optional[str] = self.alias or self.type
+        if type_:
             if (
                 self.reference or self.ref
             ) and self.python_version == PythonVersion.PY_36:
-                type_: str = f"'{self.type}'"
-            else:
-                type_ = self.type
+                type_ = f"'{type_}'"
         else:
             if len(self.data_types) > 1:
                 type_ = f"Union[{', '.join(data_type.type_hint for data_type in self.data_types)}]"
@@ -119,13 +139,17 @@ class DataType(BaseModel):
                 # type_ = 'Any'
                 type_ = ''
         if self.is_list:
-            if self.use_standard_collections:
+            if self.use_generic_container:
+                list_ = 'Sequence'
+            elif self.use_standard_collections:
                 list_ = 'list'
             else:
                 list_ = 'List'
             type_ = f'{list_}[{type_}]' if type_ else list_
         elif self.is_dict:
-            if self.use_standard_collections:
+            if self.use_generic_container:
+                dict_ = 'Mapping'
+            elif self.use_standard_collections:
                 dict_ = 'dict'
             else:
                 dict_ = 'Dict'
@@ -151,6 +175,15 @@ class DataTypeStandardCollections(DataType):
     use_standard_collections: bool = True
 
 
+class DataTypeGenericContainer(DataType):
+    use_generic_container: bool = True
+
+
+class DataTypeGenericContainerStandardCollections(DataType):
+    use_standard_collections: bool = True
+    use_generic_container: bool = True
+
+
 class Types(Enum):
     integer = auto()
     int32 = auto()
@@ -189,10 +222,25 @@ class DataTypeManager(ABC):
         self,
         python_version: PythonVersion = PythonVersion.PY_37,
         use_standard_collections: bool = False,
+        use_generic_container_types: bool = False,
     ) -> None:
         self.python_version = python_version
-        if use_standard_collections:
-            self.data_type: Type[DataType] = DataTypeStandardCollections
+        self.use_standard_collections: bool = use_standard_collections
+        self.use_generic_container_types: bool = use_generic_container_types
+
+        self.data_type: Type[DataType]
+        if use_generic_container_types:
+            if python_version == PythonVersion.PY_36:  # pragma: no cover
+                raise Exception(
+                    "use_generic_container_types can not be used with target_python_version 3.6.\n"
+                    " The verison will be not supported in a future version"
+                )
+            if use_standard_collections:
+                self.data_type = DataTypeGenericContainerStandardCollections
+            else:
+                self.data_type = DataTypeGenericContainer
+        elif use_standard_collections:
+            self.data_type = DataTypeStandardCollections
         elif python_version == PythonVersion.PY_36:
             self.data_type = DataTypePy36
         else:
