@@ -57,17 +57,21 @@ class Broken(Base):
 
 
 class Failing(Base):
-    pass
-
     class Config:
         extra = Extra.allow
 
+    __root__: str
+
 
 class Test(Base):
     broken: Optional[Dict[str, Broken]] = None
     failing: Optional[Dict[str, Failing]] = {}
 
 
+class BrokenArray(Base):
+    broken: Optional[Dict[str, List[Broken]]] = None
+
+
 class Tags(Base):
     __root__: List[str]
 
