@@ -9,7 +9,7 @@ from _pytest.capture import CaptureFixture
 from _pytest.tmpdir import TempdirFactory
 from freezegun import freeze_time
 
-from datamodel_code_generator import chdir
+from datamodel_code_generator import InputFileType, chdir, generate
 from datamodel_code_generator.__main__ import Exit, main
 
 DATA_PATH: Path = Path(__file__).parent / 'data'
@@ -831,6 +831,31 @@ def test_allow_population_by_field_name():
         main()
 
 
+@freeze_time('2019-07-26')
+def test_enable_faux_immutability():
+    with TemporaryDirectory() as output_dir:
+        output_file: Path = Path(output_dir) / 'output.py'
+        return_code: Exit = main(
+            [
+                '--input',
+                str(OPEN_API_DATA_PATH / 'api.yaml'),
+                '--output',
+                str(output_file),
+                '--enable-faux-immutability',
+            ]
+        )
+        assert return_code == Exit.OK
+        assert (
+            output_file.read_text()
+            == (
+                EXPECTED_MAIN_PATH / 'enable_faux_immutability' / 'output.py'
+            ).read_text()
+        )
+
+    with pytest.raises(SystemExit):
+        main()
+
+
 @freeze_time('2019-07-26')
 def test_use_default():
     with TemporaryDirectory() as output_dir:
@@ -1180,6 +1205,82 @@ def test_main_use_standard_collections(tmpdir_factory: TempdirFactory) -> None:
         assert result == path.read_text()
 
 
+def test_main_use_generic_container_types(tmpdir_factory: TempdirFactory) -> None:
+    output_directory = Path(tmpdir_factory.mktemp('output'))
+
+    input_filename = OPEN_API_DATA_PATH / 'modular.yaml'
+    output_path = output_directory / 'model'
+
+    with freeze_time(TIMESTAMP):
+        main(
+            [
+                '--input',
+                str(input_filename),
+                '--output',
+                str(output_path),
+                '--use-generic-container-types',
+            ]
+        )
+    main_use_generic_container_types_dir = (
+        EXPECTED_MAIN_PATH / 'main_use_generic_container_types'
+    )
+    for path in main_use_generic_container_types_dir.rglob('*.py'):
+        result = output_path.joinpath(
+            path.relative_to(main_use_generic_container_types_dir)
+        ).read_text()
+        assert result == path.read_text()
+
+
+def test_main_use_generic_container_types_standard_collections(
+    tmpdir_factory: TempdirFactory,
+) -> None:
+    output_directory = Path(tmpdir_factory.mktemp('output'))
+
+    input_filename = OPEN_API_DATA_PATH / 'modular.yaml'
+    output_path = output_directory / 'model'
+
+    with freeze_time(TIMESTAMP):
+        main(
+            [
+                '--input',
+                str(input_filename),
+                '--output',
+                str(output_path),
+                '--use-generic-container-types',
+                '--use-standard-collections',
+            ]
+        )
+    main_use_generic_container_types_standard_collections_dir = (
+        EXPECTED_MAIN_PATH / 'main_use_generic_container_types_standard_collections'
+    )
+    for path in main_use_generic_container_types_standard_collections_dir.rglob('*.py'):
+        result = output_path.joinpath(
+            path.relative_to(main_use_generic_container_types_standard_collections_dir)
+        ).read_text()
+        assert result == path.read_text()
+
+
+def test_main_use_generic_container_types_py36(capsys) -> None:
+    input_filename = OPEN_API_DATA_PATH / 'modular.yaml'
+
+    return_code: Exit = main(
+        [
+            '--input',
+            str(input_filename),
+            '--use-generic-container-types',
+            '--target-python-version',
+            '3.6',
+        ]
+    )
+    captured = capsys.readouterr()
+    assert return_code == Exit.ERROR
+    assert (
+        captured.err == '`--use-generic-container-types` can not be used with '
+        '`--target-python_version` 3.6.\n '
+        'The version will be not supported in a future version\n'
+    )
+
+
 @freeze_time('2019-07-26')
 def test_main_external_definitions():
     with TemporaryDirectory() as output_dir:
@@ -1510,6 +1611,31 @@ def test_main_json_pointer():
         main()
 
 
+@freeze_time('2019-07-26')
+def test_main_nested_json_pointer():
+    with TemporaryDirectory() as output_dir:
+        output_file: Path = Path(output_dir) / 'output.py'
+        return_code: Exit = main(
+            [
+                '--input',
+                str(JSON_SCHEMA_DATA_PATH / 'nested_json_pointer.json'),
+                '--output',
+                str(output_file),
+                '--input-file-type',
+                'jsonschema',
+            ]
+        )
+        assert return_code == Exit.OK
+        assert (
+            output_file.read_text()
+            == (
+                EXPECTED_MAIN_PATH / 'main_nested_json_pointer' / 'output.py'
+            ).read_text()
+        )
+    with pytest.raises(SystemExit):
+        main()
+
+
 @freeze_time('2019-07-26')
 def test_main_jsonschema_multiple_files_json_pointer():
     with TemporaryDirectory() as output_dir:
@@ -1649,6 +1775,66 @@ def test_main_root_model_with_additional_properties():
         main()
 
 
+@freeze_time('2019-07-26')
+def test_main_root_model_with_additional_properties_use_generic_container_types():
+    with TemporaryDirectory() as output_dir:
+        output_file: Path = Path(output_dir) / 'output.py'
+        return_code: Exit = main(
+            [
+                '--input',
+                str(
+                    JSON_SCHEMA_DATA_PATH / 'root_model_with_additional_properties.json'
+                ),
+                '--output',
+                str(output_file),
+                '--input-file-type',
+                'jsonschema',
+                '--use-generic-container-types',
+            ]
+        )
+        assert return_code == Exit.OK
+        assert (
+            output_file.read_text()
+            == (
+                EXPECTED_MAIN_PATH
+                / 'main_root_model_with_additional_properties_use_generic_container_types'
+                / 'output.py'
+            ).read_text()
+        )
+    with pytest.raises(SystemExit):
+        main()
+
+
+@freeze_time('2019-07-26')
+def test_main_root_model_with_additional_properties_use_standard_collections():
+    with TemporaryDirectory() as output_dir:
+        output_file: Path = Path(output_dir) / 'output.py'
+        return_code: Exit = main(
+            [
+                '--input',
+                str(
+                    JSON_SCHEMA_DATA_PATH / 'root_model_with_additional_properties.json'
+                ),
+                '--output',
+                str(output_file),
+                '--input-file-type',
+                'jsonschema',
+                '--use-standard-collections',
+            ]
+        )
+        assert return_code == Exit.OK
+        assert (
+            output_file.read_text()
+            == (
+                EXPECTED_MAIN_PATH
+                / 'main_root_model_with_additional_properties_use_standard_collections'
+                / 'output.py'
+            ).read_text()
+        )
+    with pytest.raises(SystemExit):
+        main()
+
+
 @freeze_time('2019-07-26')
 def test_main_root_model_with_additional_properties_literal():
     with TemporaryDirectory() as output_dir:
@@ -1836,3 +2022,86 @@ def test_main_openapi_nullable_strict_nullable():
         )
     with pytest.raises(SystemExit):
         main()
+
+
+@freeze_time('2019-07-26')
+def test_main_openapi_pattern():
+    with TemporaryDirectory() as output_dir:
+        output_file: Path = Path(output_dir) / 'output.py'
+        return_code: Exit = main(
+            [
+                '--input',
+                str(OPEN_API_DATA_PATH / 'pattern.yaml'),
+                '--output',
+                str(output_file),
+                '--input-file-type',
+                'openapi',
+            ]
+        )
+        assert return_code == Exit.OK
+        assert output_file.read_text() == (
+            EXPECTED_MAIN_PATH / 'main_pattern' / 'output.py'
+        ).read_text().replace('pattern.json', 'pattern.yaml')
+    with pytest.raises(SystemExit):
+        main()
+
+
+@freeze_time('2019-07-26')
+def test_main_jsonschema_pattern():
+    with TemporaryDirectory() as output_dir:
+        output_file: Path = Path(output_dir) / 'output.py'
+        return_code: Exit = main(
+            [
+                '--input',
+                str(JSON_SCHEMA_DATA_PATH / 'pattern.json'),
+                '--output',
+                str(output_file),
+                '--input-file-type',
+                'jsonschema',
+            ]
+        )
+        assert return_code == Exit.OK
+        assert (
+            output_file.read_text()
+            == (EXPECTED_MAIN_PATH / 'main_pattern' / 'output.py').read_text()
+        )
+    with pytest.raises(SystemExit):
+        main()
+
+
+@freeze_time('2019-07-26')
+def test_main_generate():
+    with TemporaryDirectory() as output_dir:
+        output_file: Path = Path(output_dir) / 'output.py'
+        input_ = (JSON_SCHEMA_DATA_PATH / 'person.json').relative_to(Path.cwd())
+        assert not input_.is_absolute()
+        generate(
+            input_=input_, input_file_type=InputFileType.JsonSchema, output=output_file,
+        )
+
+        assert (
+            output_file.read_text()
+            == (EXPECTED_MAIN_PATH / 'main_jsonschema' / 'output.py').read_text()
+        )
+
+
+@freeze_time('2019-07-26')
+def test_main_generate_from_directory():
+    with TemporaryDirectory() as output_dir:
+        output_path: Path = Path(output_dir)
+        input_ = (JSON_SCHEMA_DATA_PATH / 'external_files_in_directory').relative_to(
+            Path.cwd()
+        )
+        assert not input_.is_absolute()
+        assert input_.is_dir()
+        generate(
+            input_=input_, input_file_type=InputFileType.JsonSchema, output=output_path,
+        )
+
+        main_nested_directory = EXPECTED_MAIN_PATH / 'main_nested_directory'
+
+        for path in main_nested_directory.rglob('*.py'):
+            result = output_path.joinpath(
+                path.relative_to(main_nested_directory)
+            ).read_text()
+            assert result == path.read_text()
